import logging

import pytest
from sqlalchemy.orm import Session

from portal.database.models import Course, User
from portal.service.permissions import check_user

log = logging.getLogger(__name__)


@pytest.fixture
def admin_user(app):
    return User.query.filter_by(username='admin').first()


@pytest.fixture
def student_user(app):
    return User.query.filter_by(username='student1').first()


@pytest.fixture
def course(app):
    return Course.query.filter_by(codename='TestCourse1').first()


def test_project_list_with_admin_permissions(course, admin_user):
    assert check_user(admin_user, course=course,
                      permissions=['view_course_full'])


def test_project_list_with_non_admin_permissions(student_user, course):
    assert not check_user(student_user, course=course,
                          permissions=['view_course_full'])


def test_project_list_with_non_admin_permissions_limited(student_user, course):
    assert check_user(student_user, course=course,
                      permissions=['view_course_limited'])
